# -*- encoding: utf-8 -*-
#
# Author: Nejc Saje <nejc.saje@xlab.si>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from sqlalchemy import Column
from sqlalchemy import MetaData
from sqlalchemy import Table
from sqlalchemy import Text


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    alarm = Table('alarm', meta, autoload=True)
    time_constraints = Column('time_constraints', Text())
    alarm.create_column(time_constraints)


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    alarm = Table('alarm', meta, autoload=True)
    time_constraints = Column('time_constraints', Text())
    alarm.drop_column(time_constraints)
